@@ -10,11 +10,11 @@ from astro.airflow.datasets import kwargs_with_datasets
 from astro.constants import DEFAULT_CHUNK_SIZE, ColumnCapitalization, LoadExistStrategy
 from astro.databases import create_database
 from astro.databases.base import BaseDatabase
+from astro.dataframes.pandas import PandasDataframe
 from astro.files import File, check_if_connection_exists, resolve_file_path_pattern
 from astro.settings import LOAD_FILE_ENABLE_NATIVE_FALLBACK
 from astro.sql.operators.base_operator import AstroSQLBaseOperator
 from astro.table import BaseTable
-from astro.utils.dataframe import convert_dataframe_to_file
 from astro.utils.typing_compat import Context
 
 
@@ -83,13 +83,13 @@ class LoadFileOperator(AstroSQLBaseOperator):
             context["ti"].xcom_push(key="output_table_name", value=str(self.output_table.name))
         return self.load_data(input_file=self.input_file)
 
-    def load_data(self, input_file: File) -> BaseTable | File:
+    def load_data(self, input_file: File) -> BaseTable | pd.DataFrame:
 
         self.log.info("Loading %s into %s ...", self.input_file.path, self.output_table)
         if self.output_table:
             return self.load_data_to_table(input_file)
         else:
-            return convert_dataframe_to_file(self.load_data_to_dataframe(input_file))
+            return self.load_data_to_dataframe(input_file)
 
     def load_data_to_table(self, input_file: File) -> BaseTable:
         """
@@ -137,11 +137,15 @@ class LoadFileOperator(AstroSQLBaseOperator):
                         file.export_to_dataframe(
                             columns_names_capitalization=self.columns_names_capitalization
                         ),
-                    ]
+                    ],
+                    ignore_index=True,
                 )
             else:
                 df = file.export_to_dataframe(columns_names_capitalization=self.columns_names_capitalization)
 
+        if not isinstance(df, PandasDataframe):
+            df = PandasDataframe.from_pandas_df(df)
+
         self.log.info("Completed loading the data into dataframe.")
         return df
 
