@@ -46,7 +46,7 @@ class RawSQLOperator(BaseSQLDecoratedOperator):
 
         if self.handler:
             response = self.handler(result)
-            response = [SdkLegacyRow.from_legacy_row(r) if isinstance(r, SQLAlcRow) else r for r in response]
+            response = self.make_row_serializable(response)
             if 0 <= self.response_limit < len(response):
                 raise IllegalLoadToDatabaseException()  # pragma: no cover
             if self.response_size >= 0:
@@ -56,6 +56,15 @@ class RawSQLOperator(BaseSQLDecoratedOperator):
         else:
             return None
 
+    @staticmethod
+    def make_row_serializable(rows: Any) -> Any:
+        """
+        Convert rows to a serializable format
+        """
+        if isinstance(rows, Iterable):
+            return [SdkLegacyRow.from_legacy_row(r) if isinstance(r, SQLAlcRow) else r for r in rows]
+        return rows
+
 
 class SdkLegacyRow(SQLAlcRow):
     version: int = 1
